@@ -351,11 +351,14 @@ LockStruct  LockProcs[] =
 	 5000, 5, 1, 1, 64, 1.0, "",
 	 "Shows animated swirling patterns", 0, NULL, NULL},
 	{"tetris",
-   50000, 1, 1, 0, 64, 1.0, "",
-	 "Shows tetris", 0, NULL, NULL},
+	 50000, 1, 1, 0, 64, 1.0, "",
+	 "Shows an autoplaying tetris game", 0, NULL, NULL},
 	{"thornbird",
 	 1000, 800, 16, 1, 64, 1.0, "",
 	 "Shows an animated bird in a thorn bush fractal map", 0, NULL, NULL},
+	{"tik_tak",
+	 60000, -20, 200, -1000, 64, 1.0, "",
+	 "Shows rotating polygons", 0, NULL, NULL},
 	{"triangle",
 	 10000, 1, 1, 1, 64, 1.0, "",
 	 "Shows a triangle mountain range", 0, NULL, NULL},
