@@ -53,12 +53,13 @@ static const char sccsid[] = "@(#)bomb.c	4.07 97/11/24 xlockmore";
 #define UNIFORM_COLORS
 #define BRIGHT_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#include "iostuff.h"
+
+#ifdef MODE_bomb
 
-#ifdef USE_BOMB
 ModeSpecOpt bomb_opts =
 {0, NULL, 0, NULL, NULL};
 
@@ -239,7 +240,7 @@ init_bomb(ModeInfo * mi)
 		bp->startcountdown = COUNTDOWN;
 #endif
 	if (bp->countdown == 0)	/* <--Stricter if uncommented */
-		bp->countdown = (time((time_t *) NULL) + bp->startcountdown);
+		bp->countdown = (int) (time((time_t *) NULL) + bp->startcountdown);
 	/* Detonator Primed */
 
 	MI_CLEARWINDOW(mi);
@@ -272,9 +273,15 @@ explode(ModeInfo * mi)
 	char        buff[NDIGITS + 2];
 	extern void logoutUser(Display * display);
 
-#if defined(__cplusplus) || defined(c_plusplus)
+#ifdef SunCplusplus
+/* #include <signal.h> */
+	extern int  kill(pid_t, int);
+
+#else
+#if 0
 	extern int  kill(int, int);
 
+#endif
 #endif
 
 	/*
@@ -295,8 +302,8 @@ explode(ModeInfo * mi)
 #ifndef DEBUG
 	if (MI_IS_INWINDOW(mi) || MI_IS_INROOT(mi) ||
 	    MI_IS_NOLOCK(mi) || MI_IS_DEBUG(mi))
-		(void) kill(getpid(), SIGTERM);
-	else if (getuid() == 0) {	/* Do not try to logout root! */
+		(void) kill((int) getpid(), SIGTERM);
+	else if ((int) getuid() == 0) {		/* Do not try to logout root! */
 		bp->countdown = 0;
 		init_bomb(mi);
 	} else
@@ -407,4 +414,4 @@ change_bomb(ModeInfo * mi)
 	bp->moveok = 0;
 }
 
-#endif
+#endif  /* MODE_bomb */
