@@ -5,6 +5,7 @@
 static const char sccsid[] = "@(#)dclock.c	4.07 97/11/24 xlockmore";
 
 #endif
+
 /*-
  * Copyright (C) 1995 by Michael Stembera <mrbig@fc.net>.
  *
@@ -63,7 +64,7 @@ static const char sccsid[] = "@(#)dclock.c	4.07 97/11/24 xlockmore";
  *  247 hectares a minute lost forever (1 hectare = 2.47 acres)
  *
  *  HIV Infection Counter Saver (hiv)
- *  -130,828,080 cases (figured by extrapolation) 1 Jan 1970
+ *  -130,824,786 cases (figured by extrapolation) 1 Jan 1970
  *  (hmmm...)
  *  36,503,000 3 Dec 1998 (from http://www.vers.com/aidsclock/INDEXA.HTM)
  *  11 cases/min
@@ -124,7 +125,7 @@ static const char sccsid[] = "@(#)dclock.c	4.07 97/11/24 xlockmore";
 #define PEOPLE_MIN 160.70344
 #define PEOPLE_TIME_START 3535369000.0
 #define HIV_MIN 11.0
-#define HIV_TIME_START -130828080.0
+#define HIV_TIME_START -130824786.0
 #define LAB_MIN 32.32184957
 #define LAB_TIME_START 0
 #define VEG_MIN 9506.426344209
@@ -133,6 +134,13 @@ static const char sccsid[] = "@(#)dclock.c	4.07 97/11/24 xlockmore";
 #define Y2K_TIME_START (((30 * 365) + 7) * 24 * 60 * 60)
 #define Y2001_TIME_START (Y2K_TIME_START + 366 * 24 * 60 * 60)
 
+#define LED_LEAN 0.2
+#define LED_XS 30.0
+#define LED_YS 45.0
+#define LED_WIDTH (0.15 * LED_YS)
+#define LED_INC (LED_LEAN * LED_XS) /* LEAN and INC do not have to be linked */
+
+#define DEF_LED    "False"
 #define DEF_POPEX  "False"
 #define DEF_FOREST "False"
 #define DEF_HIV    "False"
@@ -141,6 +149,57 @@ static const char sccsid[] = "@(#)dclock.c	4.07 97/11/24 xlockmore";
 #define DEF_Y2K    "False"
 #define DEF_Y2001  "False"
 
+/*- If you remember your Electronics course...
+        a
+        _
+    f / / b
+      -g
+  e /_/ c
+    d
+ */
+
+#define MAX_LEDS 7
+static unsigned char digits[][MAX_LEDS]=
+{
+/* a  b  c  d  e  f  g */
+  {1, 1, 1, 1, 1, 1, 0},  /* 0 */
+  {0, 1, 1, 0, 0, 0, 0},  /* 1 */
+  {1, 1, 0, 1, 1, 0, 1},  /* 2 */
+  {1, 1, 1, 1, 0, 0, 1},  /* 3 */
+  {0, 1, 1, 0, 0, 1, 1},  /* 4 */
+  {1, 0, 1, 1, 0, 1, 1},  /* 5 */
+  {1, 0, 1, 1, 1, 1, 1},  /* 6 */
+  {1, 1, 1, 0, 0, 0, 0},  /* 7 */
+  {1, 1, 1, 1, 1, 1, 1},  /* 8 */
+  {1, 1, 1, 1, 0, 1, 1}  /* 9 */
+#if 0
+  , /* Completeness, we must have completeness */
+  {1, 1, 1, 0, 1, 1, 1},  /* A */
+  {0, 0, 1, 1, 1, 1, 1},  /* b */
+  {1, 0, 0, 1, 1, 1, 0},  /* C */
+  {0, 1, 1, 1, 1, 0, 1},  /* d */
+  {1, 0, 0, 1, 1, 1, 1},  /* E */
+  {1, 0, 0, 0, 1, 1, 1}   /* F */
+#define MAX_DIGITS 16
+#else  
+#define MAX_DIGITS 10
+#endif
+};
+
+static Bool led;
+
+/* Create an virtual parallelogram, normal rectangle parameters plus "lean":
+   the amount the start of a will be shifted to the right of the start of d.
+ */
+
+static XPoint parallelogramUnit[4] =
+{
+	{1, 0},
+	{2, 0},
+	{-1, 1},
+	{-2, 0}
+};
+
 static Bool popex;
 static Bool forest;
 static Bool hiv;
@@ -151,6 +210,8 @@ static Bool millennium;
 
 static XrmOptionDescRec opts[] =
 {
+	{"-led", ".dclock.led", XrmoptionNoArg, (caddr_t) "on"},
+	{"+led", ".dclock.led", XrmoptionNoArg, (caddr_t) "off"},
 	{"-popex", ".dclock.popex", XrmoptionNoArg, (caddr_t) "on"},
 	{"+popex", ".dclock.popex", XrmoptionNoArg, (caddr_t) "off"},
 	{"-forest", ".dclock.forest", XrmoptionNoArg, (caddr_t) "on"},
@@ -168,6 +229,7 @@ static XrmOptionDescRec opts[] =
 };
 static argtype vars[] =
 {
+	{(caddr_t *) & led, "led", "LED", DEF_LED, t_Bool},
 	{(caddr_t *) & popex, "popex", "PopEx", DEF_POPEX, t_Bool},
 	{(caddr_t *) & forest, "forest", "Forest", DEF_FOREST, t_Bool},
 	{(caddr_t *) & hiv, "hiv", "Hiv", DEF_HIV, t_Bool},
@@ -178,13 +240,14 @@ static argtype vars[] =
 };
 static OptionStruct desc[] =
 {
+	{"-/+led", "turn on/off Light Emitting Diode seven segment display"},
 	{"-/+popex", "turn on/off population explosion counter"},
 	{"-/+forest", "turn on/off tropical forest destruction counter"},
 	{"-/+hiv", "turn on/off HIV infection counter"},
 	{"-/+lab", "turn on/off Animal Research counter"},
 	{"-/+veg", "turn on/off Animal Consumation counter"},
 	{"-/+y2k", "turn on/off Year 2000 countdown"},
-	{"-/+millennium", "turn on/off 3rd Millennium (1 January 2001) countdown"}
+	{"-/+millennium", "turn on/off 3rd Millennium (1 January 2001) countdown"},
 };
 
 ModeSpecOpt dclock_opts =
@@ -219,7 +282,7 @@ ModStruct   dclock_description =
 #define Y2001_STRING "Dcompte pour le Second Millnaire (1er Janvier 2001)"
 #define POST_Y2001_STRING "Temps depuis le Second Millnaire (1er Janvier 2001)"
 #define DAY "jour"
-#define DAYS "jours"
+#define DALED_YS "jours"
 #define HOUR "heure"
 #define HOURS "heures"
 #define MINUTE "minute"
@@ -245,7 +308,7 @@ ModStruct   dclock_description =
 #define Y2001_STRING "Aftellen tot het tweede millennium (1 Januari 2001)"
 #define POST_Y2001_STRING "Tijd sinds het tweede millennium (1 Januari 2001)"
 #define DAY "dag"
-#define DAYS "dagen"
+#define DALED_YS "dagen"
 #define HOUR "uur"
 #define HOURS "uren"
 #define MINUTE "minuut"
@@ -267,7 +330,7 @@ ModStruct   dclock_description =
 #define Y2001_STRING "Countdown to the end of the Second Millennium (1 January 2001, 0:00 hour)"
 #define POST_Y2001_STRING "Time since the start of the Third Millennium (1 January 2001)"
 #define DAY "day"
-#define DAYS "days"
+#define DALED_YS "days"
 #define HOUR "hour"
 #define HOURS "hours"
 #define MINUTE "minute"
@@ -291,13 +354,15 @@ typedef struct {
 	short       maxx, maxy, clockx, clocky;
 	short       text_height, text_width, text_width1, text_width2;
 	short       text_start1, text_start2;
+	short       text_ascent, text_descent;
 	short       hour;
 	short       dx, dy;
 	int         done;
 	int         pixw, pixh;
 	Pixmap      pixmap;
 	GC          fgGC, bgGC;
-	Bool        popex, forest, hiv, lab, veg, y2k, millennium;
+	Bool        popex, forest, hiv, lab, veg, y2k, millennium, led;
+	XPoint      parallelogram[4];
 } dclockstruct;
 
 static dclockstruct *dclocks = NULL;
@@ -364,7 +429,7 @@ dayhrminsec(long timeCount, int tzoffset, char *string)
 	if (days == 1)
 		(void) strcat(string, DAY);
 	else
-		(void) strcat(string, DAYS);
+		(void) strcat(string, DALED_YS);
 	(void) sprintf(buf, ", %d ", hours);
 	(void) strcat(string, buf);
 	if (hours == 1)
@@ -389,6 +454,125 @@ dayhrminsec(long timeCount, int tzoffset, char *string)
 	buf = NULL;
 }
 
+static void
+drawaled(ModeInfo * mi, int startx, int starty, int led)
+{
+	Display    *display = MI_DISPLAY(mi);
+	dclockstruct *dp = &dclocks[MI_SCREEN(mi)];
+ 	int x_1, y_1, x_2, y_2;
+
+	int offset = LED_WIDTH; 
+	int offset2 = LED_WIDTH / 2.0; 
+	int leanoffset = offset2 * LED_LEAN; 
+
+	switch (led) {
+		case 0: /* a */
+			x_1 = startx + dp->parallelogram[0].x;
+			y_1 = starty + dp->parallelogram[0].y;
+			x_2 = x_1 + dp->parallelogram[1].x - offset;
+			y_2 = y_1 + dp->parallelogram[1].y;
+			x_1 = x_1 + offset;
+			XDrawLine(display, dp->pixmap, dp->fgGC,
+				x_1, y_1, x_2, y_2);
+			break;
+		case 1: /* b */
+			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[1].x;
+			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[1].y;
+			x_2 = x_1 + dp->parallelogram[2].x / 2 + leanoffset;
+			y_2 = y_1 + dp->parallelogram[2].y / 2 - offset2;
+			x_1 = x_1 - leanoffset;
+			y_1 = y_1 + offset2;
+			XDrawLine(display, dp->pixmap, dp->fgGC,
+				x_1, y_1, x_2, y_2);
+			break;
+		case 2: /* c */
+			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[1].x + dp->parallelogram[2].x;
+			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[1].y + dp->parallelogram[2].y;
+			x_2 = x_1 - dp->parallelogram[2].x / 2 - leanoffset;
+			y_2 = y_1 - dp->parallelogram[2].y / 2 + offset2;
+			x_1 = x_1 + leanoffset;
+			y_1 = y_1 - offset2;
+			XDrawLine(display, dp->pixmap, dp->fgGC,
+				x_1, y_1, x_2, y_2);
+			break;
+		case 3: /* d */
+			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[2].x;
+			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y;
+			x_2 = x_1 + dp->parallelogram[1].x - offset;
+			y_2 = y_1 + dp->parallelogram[1].y;
+			x_1 = x_1 + offset;
+			XDrawLine(display, dp->pixmap, dp->fgGC,
+				x_1, y_1, x_2, y_2);
+			break;
+		case 4: /* e */
+			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[2].x;
+			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y;
+			x_2 = x_1 - dp->parallelogram[2].x / 2 - leanoffset;
+			y_2 = y_1 - dp->parallelogram[2].y / 2 + offset2;
+			x_1 = x_1 + leanoffset;
+			y_1 = y_1 - offset2;
+			XDrawLine(display, dp->pixmap, dp->fgGC,
+				x_1, y_1, x_2, y_2);
+			break;
+		case 5: /* f */
+			x_1 = startx + dp->parallelogram[0].x;
+			y_1 = starty + dp->parallelogram[0].y;
+			x_2 = x_1 + dp->parallelogram[2].x / 2 + leanoffset;
+			y_2 = y_1 + dp->parallelogram[2].y / 2 - offset2;
+			x_1 = x_1 - leanoffset;
+			y_1 = y_1 + offset2;
+			XDrawLine(display, dp->pixmap, dp->fgGC,
+				x_1, y_1, x_2, y_2);
+			break;
+		case 6: /* g */
+			x_1 = startx + dp->parallelogram[0].x + dp->parallelogram[2].x / 2;
+			y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y / 2;
+			x_2 = x_1 + dp->parallelogram[1].x - offset;
+			y_2 = y_1 + dp->parallelogram[1].y;
+			x_1 = x_1 + offset;
+			XDrawLine(display, dp->pixmap, dp->fgGC,
+				x_1, y_1, x_2, y_2);
+			
+	}
+}
+
+static void
+drawacolon(ModeInfo * mi, int startx, int starty)
+{
+	Display    *display = MI_DISPLAY(mi);
+	dclockstruct *dp = &dclocks[MI_SCREEN(mi)];
+ 	int x_1, y_1, x_2, y_2;
+
+	int offset2 = LED_WIDTH / 2.0; 
+	int leanoffset = offset2 * LED_LEAN; 
+
+	x_1 = startx + dp->parallelogram[0].x +
+		dp->parallelogram[2].x / 2 - 2.0 * leanoffset;
+	y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y / 2 +
+		2.0 * offset2;
+	x_2 = x_1 - 2.0 * leanoffset;
+	y_2 = y_1 + 2.0 * offset2;
+	XDrawLine(display, dp->pixmap, dp->fgGC, x_1, y_1, x_2, y_2);
+	x_1 = startx + dp->parallelogram[0].x +
+		dp->parallelogram[2].x / 2 + 2.0 * leanoffset;
+	y_1 = starty + dp->parallelogram[0].y + dp->parallelogram[2].y / 2 -
+		2.0 * offset2;
+	x_2 = x_1 + 2.0 * leanoffset;
+	y_2 = y_1 - 2.0 * offset2;
+	XDrawLine(display, dp->pixmap, dp->fgGC, x_1, y_1, x_2, y_2);
+}
+
+static void
+drawanumber(ModeInfo * mi, int startx, int starty, int digit)
+{
+	int led;
+
+	for (led = 0; led < MAX_LEDS; led++) {
+		if (digits[digit][led])
+			drawaled(mi, startx, starty, led);
+	}
+}
+
 static void
 drawDclock(ModeInfo * mi)
 {
@@ -399,8 +583,11 @@ drawDclock(ModeInfo * mi)
 	short       xold, yold;
 	char       *tmppt;
 
-	if (!dp->popex && !dp->forest && !dp->hiv && !dp->lab && !dp->veg &&
-	    !dp->y2k && !dp->millennium) {
+	if (dp->led) {
+		dp->timeold = dp->timenew = time((time_t *) NULL);
+		dp->str = ctime(&dp->timeold);
+	} else if (!dp->popex && !dp->forest && !dp->hiv &&
+	    !dp->lab && !dp->veg && !dp->y2k && !dp->millennium) {
 		if (dp->timeold != (dp->timenew = time((time_t *) NULL))) {
 			/* only parse if time has changed */
 			dp->timeold = dp->timenew;
@@ -497,21 +684,23 @@ drawDclock(ModeInfo * mi)
 	/* Recalculate string width since it can change */
 	xold = dp->clockx;
 	yold = dp->clocky;
-	dp->text_width1 = XTextWidth(mode_font, dp->str1pta, strlen(dp->str1pta));
-	dp->text_width2 = XTextWidth(mode_font, dp->str2pta, strlen(dp->str2pta));
-	if (dp->text_width1 > dp->text_width2) {
-		dp->text_width = dp->text_width1;
-		dp->text_start1 = 0;
-		dp->text_start2 = (dp->text_width - dp->text_width2) / 2;
-	} else {
-		dp->text_width = dp->text_width2;
-		dp->text_start1 = (dp->text_width - dp->text_width1) / 2;
-		dp->text_start2 = 0;
+	if (!dp->led) {
+		dp->text_width1 = XTextWidth(mode_font, dp->str1pta, strlen(dp->str1pta));
+		dp->text_width2 = XTextWidth(mode_font, dp->str2pta, strlen(dp->str2pta));
+		if (dp->text_width1 > dp->text_width2) {
+			dp->text_width = dp->text_width1;
+			dp->text_start1 = 0;
+			dp->text_start2 = (dp->text_width - dp->text_width2) / 2;
+		} else {
+			dp->text_width = dp->text_width2;
+			dp->text_start1 = (dp->text_width - dp->text_width1) / 2;
+			dp->text_start2 = 0;
+		}
 	}
 	dp->width = MI_WIDTH(mi);
 	dp->height = MI_HEIGHT(mi);
 	dp->maxx = dp->width - dp->text_width;
-	dp->maxy = dp->height - dp->text_height - mode_font->descent;
+	dp->maxy = dp->height - dp->text_height - dp->text_descent;
 	dp->clockx += dp->dx;
 	dp->clocky += dp->dy;
 	if (dp->maxx < dp->text_start1) {
@@ -527,18 +716,19 @@ drawDclock(ModeInfo * mi)
 			dp->clockx += dp->dx;
 		}
 	}
-	if (dp->maxy < mode_font->ascent) {
-		if (dp->clocky > mode_font->ascent || dp->clocky < dp->maxy) {
+	if (dp->maxy < dp->text_ascent) {
+		if (dp->clocky > dp->text_ascent || dp->clocky < dp->maxy) {
 			dp->dy = -dp->dy;
 			dp->clocky += dp->dy;
 		}
-	} else if (dp->maxy > mode_font->ascent) {
-		if (dp->clocky > dp->maxy || dp->clocky < mode_font->ascent) {
+	} else if (dp->maxy > dp->text_ascent) {
+		if (dp->clocky > dp->maxy || dp->clocky < dp->text_ascent) {
 			dp->dy = -dp->dy;
 			dp->clocky += dp->dy;
 		}
 	}
-	if (dp->pixw != dp->text_width || dp->pixh != 2 * dp->text_height) {
+	if (dp->pixw != dp->text_width ||
+	    dp->pixh != (1 + !dp->led) * dp->text_height) {
 		XGCValues   gcv;
 
 		if (dp->fgGC)
@@ -550,7 +740,10 @@ drawDclock(ModeInfo * mi)
 			MI_CLEARWINDOWCOLORMAPFAST(mi, gc, MI_BLACK_PIXEL(mi));
 		}
 		dp->pixw = dp->text_width;
-		dp->pixh = 2 * dp->text_height;
+		if (dp->led)
+			dp->pixh = dp->text_height;
+		else
+			dp->pixh = 2 * dp->text_height;
 		dp->pixmap = XCreatePixmap(display, window, dp->pixw, dp->pixh, 1);
 		gcv.font = mode_font->fid;
 		gcv.background = 0;
@@ -561,23 +754,48 @@ drawDclock(ModeInfo * mi)
 		gcv.foreground = 0;
 		dp->bgGC = XCreateGC(display, dp->pixmap,
 				     GCForeground | GCBackground | GCGraphicsExposures | GCFont, &gcv);
+		XSetLineAttributes(MI_DISPLAY(mi), dp->fgGC,
+		  (unsigned int) (LED_WIDTH),
+		  LineSolid, CapButt, JoinMiter);
 	}
 	XFillRectangle(display, dp->pixmap, dp->bgGC, 0, 0, dp->pixw, dp->pixh);
 
-	(void) XDrawString(display, dp->pixmap, dp->fgGC,
-			   dp->text_start1, mode_font->ascent,
+	if (dp->led) {
+		int startx = LED_WIDTH / 2;
+		int starty = LED_WIDTH / 2;
+
+		drawanumber(mi, startx, starty, dp->str[11] - '0');
+		startx += LED_XS + LED_WIDTH + LED_INC;
+		drawanumber(mi, startx, starty, dp->str[12] - '0');
+		startx += LED_XS + LED_WIDTH + LED_INC;
+		drawacolon(mi, startx, starty);
+		startx += LED_WIDTH + LED_INC;
+		drawanumber(mi, startx, starty, dp->str[14] - '0');
+		startx += LED_XS + LED_WIDTH + LED_INC;
+		drawanumber(mi, startx, starty, dp->str[15] - '0');
+		startx += LED_XS + LED_WIDTH + LED_INC;
+		drawacolon(mi, startx, starty);
+		startx += LED_WIDTH + LED_INC;
+		drawanumber(mi, startx, starty, dp->str[17] - '0');
+		startx += LED_XS + LED_WIDTH + LED_INC;
+		drawanumber(mi, startx, starty, dp->str[18] - '0');
+	} else {
+		(void) XDrawString(display, dp->pixmap, dp->fgGC,
+			   dp->text_start1, dp->text_ascent,
 			   dp->str1pta, strlen(dp->str1pta));
-	(void) XDrawString(display, dp->pixmap, dp->fgGC,
-			dp->text_start2, mode_font->ascent + dp->text_height,
+		(void) XDrawString(display, dp->pixmap, dp->fgGC,
+			dp->text_start2, dp->text_ascent + dp->text_height,
 			   dp->str2pta, strlen(dp->str2pta));
+	}
+
 	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 	/* This could leave screen dust on the screen if the width changes
 	   But that only happens once a day...
 	   ... this is solved by the ClearWindow above
 	 */
 	ERASE_IMAGE(display, window, gc,
-	    (dp->clockx - dp->text_start1), (dp->clocky - mode_font->ascent),
-		    (xold - dp->text_start1), (yold - mode_font->ascent),
+	    (dp->clockx - dp->text_start1), (dp->clocky - dp->text_ascent),
+		    (xold - dp->text_start1), (yold - dp->text_ascent),
 		    dp->pixw, dp->pixh);
 	if (MI_NPIXELS(mi) > 2)
 		XSetForeground(display, gc, MI_PIXEL(mi, dp->color));
@@ -585,7 +803,7 @@ drawDclock(ModeInfo * mi)
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 	XCopyPlane(display, dp->pixmap, window, gc,
 		   0, 0, dp->text_width, 2 * dp->text_height,
-		dp->clockx - dp->text_start1, dp->clocky - mode_font->ascent,
+		dp->clockx - dp->text_start1, dp->clocky - dp->text_ascent,
 		   1L);
 }
 
@@ -612,6 +830,7 @@ init_dclock(ModeInfo * mi)
 
 	MI_CLEARWINDOW(mi);
 
+	dp->led = False;
 	dp->popex = False;
 	dp->forest = False;
 	dp->hiv = False;
@@ -620,7 +839,10 @@ init_dclock(ModeInfo * mi)
 	dp->y2k = False;
 	dp->millennium = False;
 	if (MI_IS_FULLRANDOM(mi)) {
-		switch (NRAND(8)) {
+		switch (NRAND(9)) {
+			case 0:
+				dp->led = True;
+				break;
 			case 1:
 				dp->popex = True;
 				break;
@@ -646,6 +868,7 @@ init_dclock(ModeInfo * mi)
 				break;
 		}
 	} else { /* first come, first served */
+		dp->led = led;
 		dp->popex = popex;
 		dp->forest = forest;
 		dp->hiv = hiv;
@@ -683,123 +906,158 @@ init_dclock(ModeInfo * mi)
 
 	timeNow = seconds();
 	timeLocal = timeNow - dp->tzoffset;
-	if (dp->popex) {
-		dp->str1pta = POPEX_STRING;
-		dp->str1ptb = dp->str1pta;
-	} else if (dp->forest) {
-		dp->str1pta = FOREST_STRING;
-		dp->str1ptb = dp->str1pta;
-	} else if (dp->hiv) {
-		dp->str1pta = HIV_STRING;
-		dp->str1ptb = dp->str1pta;
-	} else if (dp->lab) {
-		dp->str1pta = LAB_STRING;
-		dp->str1ptb = dp->str1pta;
-	} else if (dp->veg) {
-		dp->str1pta = VEG_STRING;
-		dp->str1ptb = dp->str1pta;
-	} else if (dp->y2k) {
-		if (Y2K_TIME_START >= timeLocal)
-			dp->str1pta = Y2K_STRING;
-		else
-			dp->str1pta = POST_Y2K_STRING;
-		dp->str1ptb = dp->str1pta;
-	} else if (dp->millennium) {
-		if (Y2001_TIME_START >= timeLocal)
-			dp->str1pta = Y2001_STRING;
-		else
-			dp->str1pta = POST_Y2001_STRING;
-		dp->str1ptb = dp->str1pta;
-	} else {
-		(void) strncpy(dp->str1, (dp->str + 11), 8);
-		dp->hour = (short) (dp->str1[0] - 48) * 10 + (short) (dp->str1[1] - 48);
-		if (dp->hour > 12) {
-			dp->hour -= 12;
-			(void) strcpy(dp->str1 + 8, " PM");
-		} else {
-			if (dp->hour == 0)
-				dp->hour += 12;
-			(void) strcpy(dp->str1 + 8, " AM");
+	if (dp->led) {
+		int i;
+
+		dp->text_descent = 0;
+		dp->text_ascent = 0;
+		for (i = 0; i < 4; i++) {
+			if (parallelogramUnit[i].x == 1)
+				dp->parallelogram[i].x = (LED_XS * LED_LEAN);
+			else if (parallelogramUnit[i].x == 2)
+				dp->parallelogram[i].x = LED_XS;
+			else if (parallelogramUnit[i].x == -1)
+				dp->parallelogram[i].x = (-LED_XS * LED_LEAN);
+			else if (parallelogramUnit[i].x == -2)
+				dp->parallelogram[i].x = -LED_XS;
+			else
+				dp->parallelogram[i].x = 0;
+			dp->parallelogram[i].y = LED_YS * parallelogramUnit[i].y;
 		}
-		dp->str1[0] = (dp->hour / 10) + 48;
-		dp->str1[1] = (dp->hour % 10) + 48;
-		if (dp->str1[0] == '0')
-			dp->str1[0] = ' ';
-		dp->str1[11] = 0;	/* terminate dp->str1 */
-		dp->str1old[11] = 0;	/* terminate dp->str1old */
 
-		(void) strncpy(dp->str2, dp->str, 11);
-		(void) strncpy(dp->str2 + 11, (dp->str + 20), 4);
-		dp->str2[15] = 0;	/* terminate dp->str2 */
-		dp->str2old[15] = 0;	/* terminate dp->str2old */
-
-		dp->str1pta = dp->str1;
-		dp->str1ptb = dp->str1old;
-	}
-	if (dp->popex) {
-		convert(PEOPLE_TIME_START + (PEOPLE_MIN / 60.0) * timeNow, dp->str2);
-		(void) strcat(dp->str2, PEOPLE_STRING);
-		dp->str2pta = dp->str2;
-		dp->str2ptb = dp->str2pta;
-	} else if (dp->forest) {
-		convert(AREA_TIME_START - (AREA_MIN / 60.0) * timeNow, dp->str2);
-		(void) strcat(dp->str2, TROPICAL_STRING);
-		(void) strcat(dp->str2, AREA_STRING);
-		dp->str2pta = dp->str2;
-		dp->str2ptb = dp->str2pta;
-	} else if (dp->hiv) {
-		convert(HIV_TIME_START + (HIV_MIN / 60.0) * timeNow, dp->str2);
-		(void) strcat(dp->str2, CASES_STRING);
-		dp->str2pta = dp->str2;
-		dp->str2ptb = dp->str2pta;
-	} else if (dp->lab) {
-		convert((LAB_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
-			dp->str2);
-		(void) strcat(dp->str2, YEAR_STRING);
-		dp->str2pta = dp->str2;
-		dp->str2ptb = dp->str2pta;
-	} else if (dp->veg) {
-		convert((VEG_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
-			dp->str2);
-		(void) strcat(dp->str2, YEAR_STRING);
-		dp->str2pta = dp->str2;
-	} else if (dp->y2k) {
-		dayhrminsec(Y2K_TIME_START - timeLocal, dp->tzoffset, dp->str2);
-		dp->str2pta = dp->str2;
-	} else if (dp->millennium) {
-		dayhrminsec(Y2001_TIME_START - timeLocal, dp->tzoffset, dp->str2);
-		dp->str2pta = dp->str2;
+		dp->parallelogram[0].x = (LED_XS * LED_LEAN) + LED_INC;
+		dp->parallelogram[0].y = 0 + LED_INC;
+		dp->text_width = 6 * (LED_XS + LED_WIDTH + LED_INC) +
+		  2 * (LED_WIDTH + LED_INC) + LED_XS * LED_LEAN - LED_INC;
+		dp->text_height = LED_YS + LED_WIDTH + LED_INC;
+		dp->maxy = dp->height - dp->text_height;
+		if (dp->maxy == 0)
+			dp->clocky = 0;
+		else if (dp->maxy < 0)
+			dp->clocky = -NRAND(-dp->maxy);
+		else
+			dp->clocky = NRAND(dp->maxy);
 	} else {
-		dp->str2pta = dp->str2;
-		dp->str2ptb = dp->str2old;
-	}
+		dp->text_descent = mode_font->descent;
+		dp->text_ascent = mode_font->ascent;
+		if (dp->popex) {
+			dp->str1pta = POPEX_STRING;
+			dp->str1ptb = dp->str1pta;
+		} else if (dp->forest) {
+			dp->str1pta = FOREST_STRING;
+			dp->str1ptb = dp->str1pta;
+		} else if (dp->hiv) {
+			dp->str1pta = HIV_STRING;
+			dp->str1ptb = dp->str1pta;
+		} else if (dp->lab) {
+			dp->str1pta = LAB_STRING;
+			dp->str1ptb = dp->str1pta;
+		} else if (dp->veg) {
+			dp->str1pta = VEG_STRING;
+			dp->str1ptb = dp->str1pta;
+		} else if (dp->y2k) {
+			if (Y2K_TIME_START >= timeLocal)
+				dp->str1pta = Y2K_STRING;
+			else
+				dp->str1pta = POST_Y2K_STRING;
+			dp->str1ptb = dp->str1pta;
+		} else if (dp->millennium) {
+			if (Y2001_TIME_START >= timeLocal)
+				dp->str1pta = Y2001_STRING;
+			else
+				dp->str1pta = POST_Y2001_STRING;
+			dp->str1ptb = dp->str1pta;
+		} else {
+			(void) strncpy(dp->str1, (dp->str + 11), 8);
+			dp->hour = (short) (dp->str1[0] - 48) * 10 + (short) (dp->str1[1] - 48);
+			if (dp->hour > 12) {
+				dp->hour -= 12;
+				(void) strcpy(dp->str1 + 8, " PM");
+			} else {
+				if (dp->hour == 0)
+					dp->hour += 12;
+				(void) strcpy(dp->str1 + 8, " AM");
+			}
+			dp->str1[0] = (dp->hour / 10) + 48;
+			dp->str1[1] = (dp->hour % 10) + 48;
+			if (dp->str1[0] == '0')
+				dp->str1[0] = ' ';
+			dp->str1[11] = 0;	/* terminate dp->str1 */
+			dp->str1old[11] = 0;	/* terminate dp->str1old */
 
-	dp->text_height = font_height(mode_font);
-	dp->text_width1 = XTextWidth(mode_font, dp->str1pta, strlen(dp->str1pta));
-	dp->text_width2 = XTextWidth(mode_font, dp->str2pta, strlen(dp->str2pta));
-	if (dp->text_width1 > dp->text_width2) {
-		dp->text_width = dp->text_width1;
-		dp->text_start1 = 0;
-		dp->text_start2 = (dp->text_width - dp->text_width2) / 2;
-	} else {
-		dp->text_width = dp->text_width2;
-		dp->text_start1 = (dp->text_width - dp->text_width1) / 2;
-		dp->text_start2 = 0;
+			(void) strncpy(dp->str2, dp->str, 11);
+			(void) strncpy(dp->str2 + 11, (dp->str + 20), 4);
+			dp->str2[15] = 0;	/* terminate dp->str2 */
+			dp->str2old[15] = 0;	/* terminate dp->str2old */
+
+			dp->str1pta = dp->str1;
+			dp->str1ptb = dp->str1old;
+		}
+		if (dp->popex) {
+			convert(PEOPLE_TIME_START + (PEOPLE_MIN / 60.0) * timeNow, dp->str2);
+			(void) strcat(dp->str2, PEOPLE_STRING);
+			dp->str2pta = dp->str2;
+			dp->str2ptb = dp->str2pta;
+		} else if (dp->forest) {
+			convert(AREA_TIME_START - (AREA_MIN / 60.0) * timeNow, dp->str2);
+			(void) strcat(dp->str2, TROPICAL_STRING);
+			(void) strcat(dp->str2, AREA_STRING);
+			dp->str2pta = dp->str2;
+			dp->str2ptb = dp->str2pta;
+		} else if (dp->hiv) {
+			convert(HIV_TIME_START + (HIV_MIN / 60.0) * timeNow, dp->str2);
+			(void) strcat(dp->str2, CASES_STRING);
+			dp->str2pta = dp->str2;
+			dp->str2ptb = dp->str2pta;
+		} else if (dp->lab) {
+			convert((LAB_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
+				dp->str2);
+			(void) strcat(dp->str2, YEAR_STRING);
+			dp->str2pta = dp->str2;
+			dp->str2ptb = dp->str2pta;
+		} else if (dp->veg) {
+			convert((VEG_MIN / 60.0) * (timeNow - timeAtLastNewYear(timeNow)),
+				dp->str2);
+			(void) strcat(dp->str2, YEAR_STRING);
+			dp->str2pta = dp->str2;
+		} else if (dp->y2k) {
+			dayhrminsec(Y2K_TIME_START - timeLocal, dp->tzoffset, dp->str2);
+			dp->str2pta = dp->str2;
+		} else if (dp->millennium) {
+			dayhrminsec(Y2001_TIME_START - timeLocal, dp->tzoffset, dp->str2);
+			dp->str2pta = dp->str2;
+		} else {
+			dp->str2pta = dp->str2;
+			dp->str2ptb = dp->str2old;
+		}
+
+		dp->text_height = font_height(mode_font);
+		dp->text_width1 = XTextWidth(mode_font, dp->str1pta, strlen(dp->str1pta));
+		dp->text_width2 = XTextWidth(mode_font, dp->str2pta, strlen(dp->str2pta));
+		if (dp->text_width1 > dp->text_width2) {
+			dp->text_width = dp->text_width1;
+			dp->text_start1 = 0;
+			dp->text_start2 = (dp->text_width - dp->text_width2) / 2;
+		} else {
+			dp->text_width = dp->text_width2;
+			dp->text_start1 = (dp->text_width - dp->text_width1) / 2;
+			dp->text_start2 = 0;
+		}
+		dp->maxy = dp->height - dp->text_height - dp->text_descent;
+		if (dp->maxy - dp->text_ascent == 0)
+			dp->clocky = dp->text_ascent;
+		else if (dp->maxy - dp->text_ascent < 0)
+			dp->clocky = -NRAND(dp->text_ascent - dp->maxy) + dp->text_ascent;
+		else
+			dp->clocky = NRAND(dp->maxy - dp->text_ascent) + dp->text_ascent;
 	}
 	dp->maxx = dp->width - dp->text_width;
-	dp->maxy = dp->height - dp->text_height - mode_font->descent;
 	if (dp->maxx == 0)
 		dp->clockx = dp->text_start1;
 	else if (dp->maxx < 0)
 		dp->clockx = -NRAND(-dp->maxx) + dp->text_start1;
 	else
 		dp->clockx = NRAND(dp->maxx) + dp->text_start1;
-	if (dp->maxy - mode_font->ascent == 0)
-		dp->clocky = mode_font->ascent;
-	else if (dp->maxy - mode_font->ascent < 0)
-		dp->clocky = -NRAND(mode_font->ascent - dp->maxy) + mode_font->ascent;
-	else
-		dp->clocky = NRAND(dp->maxy - mode_font->ascent) + mode_font->ascent;
 
 	if (MI_NPIXELS(mi) > 2)
 		dp->color = NRAND(MI_NPIXELS(mi));
