@@ -73,38 +73,43 @@ static const char sccsid[] = "@(#)dilemma.c	4.07 97/11/24 xlockmore";
  "*ncolors: 6 \n" \
  "*neighbors: 0 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "automata.h"
 #define UNIFORM_COLORS
 #define BRIGHT_COLORS
 #define SMOOTH_COLORS
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#include "automata.h"
+
+#ifdef MODE_dilemma
 
 /*-
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
  */
-extern int  neighbors;
-
+#define DEF_NEIGHBORS  "0"      /* choose random value */
 #define DEF_BONUS  "1.85"
 #define DEF_CONSCIOUS  "True"
 
+static int  neighbors;
 static float bonus;
 static Bool conscious;
 
 static XrmOptionDescRec opts[] =
 {
+	{"-neighbors", ".dilemma.neighbors", XrmoptionSepArg, (caddr_t) NULL},
 	{"-bonus", ".dilemma.bonus", XrmoptionSepArg, (caddr_t) NULL},
 	{"-conscious", ".dilemma.conscious", XrmoptionNoArg, (caddr_t) "on"},
 	{"+conscious", ".dilemma.conscious", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
+	{(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int},
 	{(caddr_t *) & bonus, "bonus", "Bonus", DEF_BONUS, t_Float},
    {(caddr_t *) & conscious, "conscious", "Conscious", DEF_CONSCIOUS, t_Bool}
 };
 static OptionStruct desc[] =
 {
+	{"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"},
 	{"-bonus value", "bonus for cheating... between 1.0 and 4.0"},
 	{"-/+conscious", "turn on/off self-awareness"}
 };
@@ -205,8 +210,8 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		dp->shape.hexagon[0].x = dp->xb + ccol * dp->xs;
 		dp->shape.hexagon[0].y = dp->yb + crow * dp->ys;
 		if (dp->xs == 1 && dp->ys == 1)
-			XFillRectangle(display, window, gc,
-			dp->shape.hexagon[0].x, dp->shape.hexagon[0].y, 1, 1);
+			XDrawPoint(display, window, gc,
+			dp->shape.hexagon[0].x, dp->shape.hexagon[0].y);
 		else if (bitmap == BITMAPS - 1)
 			XFillPolygon(display, window, gc,
 			    dp->shape.hexagon, 6, Convex, CoordModePrevious);
@@ -230,10 +235,10 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		}
 	} else if (dp->neighbors == 4 || dp->neighbors == 8) {
 		if (dp->pixelmode) {
-			if (bitmap == BITMAPS - 1 || (dp->xs == 1 && dp->ys == 1))
+			if (bitmap == BITMAPS - 1 || (dp->xs <= 2 || dp->ys <= 2))
 				XFillRectangle(display, window, gc,
 				dp->xb + dp->xs * col, dp->yb + dp->ys * row,
-					       dp->xs, dp->ys);
+				dp->xs - (dp->xs > 3), dp->ys - (dp->ys > 3));
 			else {
 				if (firstChange) {
 					XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
@@ -243,7 +248,8 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 					XSetForeground(display, gc, colour);
 				}
 				XFillArc(display, window, gc,
-					 dp->xb + dp->xs * col, dp->yb + dp->ys * row, dp->xs, dp->ys,
+					 dp->xb + dp->xs * col, dp->yb + dp->ys * row,
+					 dp->xs - 1, dp->ys - 1,
 					 0, 23040);
 			}
 		} else
@@ -257,9 +263,9 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		dp->shape.triangle[orient][0].x = dp->xb + col * dp->xs;
 		dp->shape.triangle[orient][0].y = dp->yb + row * dp->ys;
 		if (dp->xs <= 3 || dp->ys <= 3)
-			XFillRectangle(display, window, gc,
+			XDrawPoint(display, window, gc,
 			((orient) ? -1 : 1) + dp->shape.triangle[orient][0].x,
-				       dp->shape.triangle[orient][0].y, 1, 1);
+				       dp->shape.triangle[orient][0].y);
 		else {
 			if (orient)
 				dp->shape.triangle[orient][0].x += (dp->xs / 2 - 1);
@@ -652,7 +658,7 @@ init_dilemma(ModeInfo * mi)
 	}
 
 	if (dp->neighbors == 6) {
-		int         nccols, ncrows, i;
+		int         nccols, ncrows, sides;
 
 		if (dp->width < 2)
 			dp->width = 2;
@@ -677,9 +683,10 @@ init_dilemma(ModeInfo * mi)
 		dp->nrows = 2 * (ncrows / 4);
 		dp->xb = (dp->width - dp->xs * nccols) / 2 + dp->xs / 2;
 		dp->yb = (dp->height - dp->ys * (ncrows / 2) * 2) / 2 + dp->ys;
-		for (i = 0; i < 6; i++) {
-			dp->shape.hexagon[i].x = (dp->xs - 1) * hexagonUnit[i].x;
-			dp->shape.hexagon[i].y = ((dp->ys - 1) * hexagonUnit[i].y / 2) * 4 / 3;
+		for (sides = 0; sides < 6; sides++) {
+			dp->shape.hexagon[sides].x = (dp->xs - 1) * hexagonUnit[sides].x;
+			dp->shape.hexagon[sides].y =
+				((dp->ys - 1) * hexagonUnit[sides].y / 2) * 4 / 3;
 		}
 	} else if (dp->neighbors == 4 || dp->neighbors == 8) {
 		if (dp->width < 2)
@@ -715,7 +722,7 @@ init_dilemma(ModeInfo * mi)
 		dp->xb = (dp->width - dp->xs * dp->ncols) / 2;
 		dp->yb = (dp->height - dp->ys * dp->nrows) / 2;
 	} else {		/* TRI */
-		int         orient, i;
+		int         orient, sides;
 
 		if (dp->width < 2)
 			dp->width = 2;
@@ -739,11 +746,11 @@ init_dilemma(ModeInfo * mi)
 		dp->xb = (dp->width - dp->xs * dp->ncols) / 2 + dp->xs / 2;
 		dp->yb = (dp->height - dp->ys * dp->nrows) / 2 + dp->ys / 2;
 		for (orient = 0; orient < 2; orient++) {
-			for (i = 0; i < 3; i++) {
-				dp->shape.triangle[orient][i].x =
-					(dp->xs - 2) * triangleUnit[orient][i].x;
-				dp->shape.triangle[orient][i].y =
-					(dp->ys - 2) * triangleUnit[orient][i].y;
+			for (sides = 0; sides < 3; sides++) {
+				dp->shape.triangle[orient][sides].x =
+					(dp->xs - 2) * triangleUnit[orient][sides].x;
+				dp->shape.triangle[orient][sides].y =
+					(dp->ys - 2) * triangleUnit[orient][sides].y;
 			}
 		}
 	}
@@ -826,6 +833,8 @@ draw_dilemma(ModeInfo * mi)
 	dilemmastruct *dp = &dilemmas[MI_SCREEN(mi)];
 	int         col, row, mrow, colrow, n, i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (dp->state >= 2 * COLORS) {
 
 		for (col = 0; col < dp->ncols; col++) {
@@ -926,3 +935,5 @@ refresh_dilemma(ModeInfo * mi)
 	dp->redrawing = 1;
 	dp->redrawpos = 0;
 }
+
+#endif /* MODE_dilemma */
