@@ -38,9 +38,7 @@ static const char sccsid[] = "@(#)moebius.c	4.08 97/01/04 xlockmore";
  * Since I'm not a native English speaker, my apologies for any grammatical
  * mistake.
  *
- * My e-mail addresses are
- * vianna@cat.cbpf.br 
- *         and
+ * My e-mail address is
  * m-vianna@usa.net
  *
  * Marcelo F. Vianna (Jun-01-1997)
@@ -92,7 +90,7 @@ static const char sccsid[] = "@(#)moebius.c	4.08 97/01/04 xlockmore";
 #include "vis.h"
 #endif /* !STANDALONE */
 
-#ifdef USE_GL
+#ifdef MODE_moebius
 
 
 #include <GL/glu.h>
