@@ -1460,7 +1460,7 @@ rotateFace(rubikstruct * rp, int face, int direction)
 
 /* Yeah this is big and ugly */
 static void
-slideRC(rubikstruct * rp, int face, int direction, int h, int sizeOnOppAxis,
+slideRC(int face, int direction, int h, int sizeOnOppAxis,
 	int *newFace, int *newDirection, int *newH,
 	int *rotate, Bool *reverse)
 {
@@ -1558,7 +1558,7 @@ moveRubik(rubikstruct * rp, int face, int direction, int position)
 	if (rp->degreeTurn == 180) {
 		int sizeOnDepthAxis;
 
-		slideRC(rp, face, direction, h, sizeOnOppAxis,
+		slideRC(face, direction, h, sizeOnOppAxis,
 			&newFace, &newDirection, &newH, &rotate, &reverse);
 		sizeOnDepthAxis = sizeFace(rp, newFace) / sizeOnOppAxis;
 		readRC(rp, newFace, newDirection, newH, 1, sizeOnDepthAxis);
@@ -1569,7 +1569,7 @@ moveRubik(rubikstruct * rp, int face, int direction, int position)
 		direction = newDirection;
 		h = newH;
 		for (k = 2; k <= MAXORIENT + 1; k++) {
-			slideRC(rp, face, direction, h, sizeOnOppAxis,
+			slideRC(face, direction, h, sizeOnOppAxis,
 				&newFace, &newDirection, &newH, &rotate, &reverse);
 			if (k != MAXORIENT && k != MAXORIENT + 1)
 				readRC(rp, newFace, newDirection, newH, k,
@@ -1594,7 +1594,7 @@ moveRubik(rubikstruct * rp, int face, int direction, int position)
 		}
 	} else {
 		for (k = 1; k <= MAXORIENT; k++) {
-			slideRC(rp, face, direction, h, sizeOnOppAxis,
+			slideRC(face, direction, h, sizeOnOppAxis,
 				&newFace, &newDirection, &newH, &rotate, &reverse);
 			if (k != MAXORIENT)
 				readRC(rp, newFace, newDirection, newH, k, sizeOnAxis);
