@@ -873,7 +873,7 @@ static void
 	    for (int j = 0; j < contour->nPoints; ++j)
 	    {
 		FTGlyphVectorizer::POINT * point = contour->points + j;
-		delete[]point->data;
+		delete[](double *) point->data;
 		point->data = 0;
 	    }
 	}
@@ -902,8 +902,6 @@ void
 {
     int screen = MI_SCREEN(mi);
     text3dstruct *tp;
-    Display *display = MI_DISPLAY(mi);
-    Window window = MI_WINDOW(mi);
     char *fontfile = (char *) NULL;
 
     if (text3d == NULL)
@@ -1039,6 +1037,7 @@ void
 				       MI_NUM_SCREENS(mi)));
 	}
     }
+    glDrawBuffer(GL_BACK);
     glXMakeCurrent(display, window, *(tp->glx_context));
 
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
@@ -1117,6 +1116,7 @@ void
 	return;
 #endif
 
+    glDrawBuffer(GL_BACK);
     glXMakeCurrent(MI_DISPLAY(mi), MI_WINDOW(mi), *(tp->glx_context));
 }
 
