@@ -129,6 +129,10 @@ ModStruct   hyper_description =
 
 #endif
 
+#if DEBUG
+#include <assert.h>
+#endif
+
 typedef struct {
 	double      x, y;
 } dpoint;
@@ -347,7 +351,9 @@ figure_points(ModeInfo * mi)
 	 * First, figure out the points.
 	 */
 	hp->num_points = figure_num_points(hp->num_d);
-	/* assert(num_points <= max_points); */
+#if DEBUG
+	assert(hp->num_points <= hp->max_points);
+#endif
 	hp->points = allocarray(vector, hp->num_points * hp->num_mat);
 	hp->xpoints[0] = allocarray(XPoint, hp->num_points);
 	hp->xpoints[1] = allocarray(XPoint, hp->num_points);
@@ -369,7 +375,7 @@ figure_points(ModeInfo * mi)
 		n++;
 	} while (IncMultiCounter(c, hp->num_d));
 	(void) free((void *) c);
-#if 0
+#if DEBUG
 	assert(hp->num_points == n);
 #endif
 	/*
@@ -382,7 +388,9 @@ figure_points(ModeInfo * mi)
 		pix = NRAND(MI_NPIXELS(mi));
 
 	hp->num_lines = figure_num_lines(hp->num_d);
-	/* assert(hp->num_lines <= hp->max_lines); */
+#if DEBUG
+	assert(hp->num_lines <= hp->max_lines);
+#endif
 	hp->lines = (line_segment *) malloc(hp->num_lines * sizeof (line_segment));
 	for (n = i = 0; i < hp->num_points; i++) {
 		for (j = i + 1; j < hp->num_points; j++) {
@@ -404,7 +412,7 @@ figure_points(ModeInfo * mi)
 			}
 		}
 	}
-#if 0
+#if DEBUG
 	assert(hp->num_lines == n);
 #endif
 
@@ -412,7 +420,7 @@ figure_points(ModeInfo * mi)
 	 * Now determine the planes of rotation.
 	 */
 	hp->num_planes = figure_num_planes(hp->num_d);
-#if 0
+#if DEBUG
 	assert(hp->num_planes <= max_planes);
 #endif
 	hp->show_planes = show_planes;
@@ -467,7 +475,7 @@ figure_points(ModeInfo * mi)
 			hp->rotation_planes[n].y = j;
 			n++;
 		}
-#if 0
+#if DEBUG
 	assert(hp->num_planes == n);
 #endif
 	/*
@@ -788,10 +796,10 @@ move_number(ModeInfo * mi, int axis, char *string, int set, long color)
 	if (hp->normxor) {
 		XSetForeground(display, gc, color);
 		if (!hp->redrawing)
-			XDrawString(display, window, gc,
+			(void) XDrawString(display, window, gc,
 			hp->xpoints[!set][axis].x, hp->xpoints[!set][axis].y,
 				    string, strlen(string));
-		XDrawString(display, window, gc,
+		(void) XDrawString(display, window, gc,
 			  hp->xpoints[set][axis].x, hp->xpoints[set][axis].y,
 			    string, strlen(string));
 	} else {
@@ -800,11 +808,11 @@ move_number(ModeInfo * mi, int axis, char *string, int set, long color)
 				XSetForeground(display, gc, MI_NONE_COLOR(mi));
 			else
 				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-			XDrawString(display, window, gc,
+			(void) XDrawString(display, window, gc,
 			  hp->xpoints[set][axis].x, hp->xpoints[set][axis].y,
 				    string, strlen(string));
 			if (MI_IS_USE3D(mi))
-				XDrawString(display, window, gc,
+				(void) XDrawString(display, window, gc,
 					    hp->xpointsleft[set][axis].x, hp->xpointsleft[set][axis].y,
 					    string, strlen(string));
 		}
@@ -817,12 +825,12 @@ move_number(ModeInfo * mi, int axis, char *string, int set, long color)
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 		else
 			XSetForeground(display, gc, color);
-		XDrawString(display, window, gc,
+		(void) XDrawString(display, window, gc,
 			hp->xpoints[!set][axis].x, hp->xpoints[!set][axis].y,
 			    string, strlen(string));
 		if (MI_IS_USE3D(mi)) {
 			XSetForeground(display, gc, MI_RIGHT_COLOR(mi));
-			XDrawString(display, window, gc,
+			(void) XDrawString(display, window, gc,
 				    hp->xpointsleft[!set][axis].x, hp->xpointsleft[!set][axis].y,
 				    string, strlen(string));
 			if (MI_IS_INSTALL(mi)) {
