@@ -139,7 +139,6 @@ make_starfish(ModeInfo * mi)
 {
 	starfishstruct *sp = &starfishes[MI_SCREEN(mi)];
 	int         i;
-	int         mid;
 
 	sp->elasticity = SCALE * sp->thickness;
 
@@ -189,7 +188,7 @@ make_starfish(ModeInfo * mi)
 
 	if (sp->min_r < (5 * SCALE))
 		sp->min_r = (5 * SCALE);
-	mid = ((sp->min_r + sp->max_r) / 2);
+	/* mid = ((sp->min_r + sp->max_r) / 2); */
 
 	sp->x = sp->winwidth / 2;
 	sp->y = sp->winheight / 2;
