@@ -46,13 +46,33 @@ static const char sccsid[] = "@(#)voters.c	4.07 97/11/24 xlockmore";
 #endif /* STANDALONE */
 #include "automata.h"
 
+#ifdef MODE_voters
+
 /*-
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
  */
-extern int  neighbors;
+#define DEF_NEIGHBORS  "0"      /* choose random value */
+
+static int  neighbors;
+
+static XrmOptionDescRec opts[] =
+{
+        {"-neighbors", ".voters.neighbors", XrmoptionSepArg, (caddr_t) NULL}
+};
+
+static argtype vars[] =
+{
+        {(caddr_t *) & neighbors, "neighbors", "Neighbors", DEF_NEIGHBORS, t_Int
+}
+};
+static OptionStruct desc[] =
+{
+        {"-neighbors num", "squares 4 or 8, hexagons 6, triangles 3, 9 or 12"}
+};
 
 ModeSpecOpt voters_opts =
-{0, NULL, 0, NULL, NULL};
+{sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
+
 
 #ifdef USE_MODULES
 ModStruct   voters_description =
@@ -63,8 +83,6 @@ ModStruct   voters_description =
 
 #endif
 
-extern int  neighbors;
-
 /*-
  * From far left to right, at least in the currently in the US.  By the way, I
  * consider myself to be a proud bleeding heart liberal democrat, in
@@ -148,8 +166,8 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		vp->hexagonList[0].x = vp->xb + ccol * vp->xs;
 		vp->hexagonList[0].y = vp->yb + crow * vp->ys;
 		if (vp->xs == 1 && vp->ys == 1)
-			XFillRectangle(display, window, gc,
-			   vp->hexagonList[0].x, vp->hexagonList[0].y, 1, 1);
+			XDrawPoint(display, window, gc,
+			   vp->hexagonList[0].x, vp->hexagonList[0].y);
 		else if (bitmap == BITMAPS - 1)
 			XFillPolygon(display, window, gc,
 			      vp->hexagonList, 6, Convex, CoordModePrevious);
@@ -201,9 +219,9 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		vp->triangleList[orient][0].x = vp->xb + col * vp->xs;
 		vp->triangleList[orient][0].y = vp->yb + row * vp->ys;
 		if (vp->xs <= 3 || vp->ys <= 3)
-			XFillRectangle(display, window, gc,
+			XDrawPoint(display, window, gc,
 			 ((orient) ? -1 : 1) + vp->triangleList[orient][0].x,
-				       vp->triangleList[orient][0].y, 1, 1);
+				       vp->triangleList[orient][0].y);
 		else {
 			if (orient)
 				vp->triangleList[orient][0].x += (vp->xs / 2 - 1);
@@ -593,7 +611,7 @@ init_voters(ModeInfo * mi)
 	}
 
 	if (vp->neighbors == 6) {
-		int         nccols, ncrows, i;
+		int         nccols, ncrows, sides;
 
 		if (vp->width < 2)
 			vp->width = 2;
@@ -618,9 +636,10 @@ init_voters(ModeInfo * mi)
 		vp->nrows = 2 * (ncrows / 4);
 		vp->xb = (vp->width - vp->xs * nccols) / 2 + vp->xs / 2;
 		vp->yb = (vp->height - vp->ys * (ncrows / 2) * 2) / 2 + vp->ys;
-		for (i = 0; i < 6; i++) {
-			vp->hexagonList[i].x = (vp->xs - 1) * hexagonUnit[i].x;
-			vp->hexagonList[i].y = ((vp->ys - 1) * hexagonUnit[i].y / 2) * 4 / 3;
+		for (sides = 0; sides < 6; sides++) {
+			vp->hexagonList[sides].x = (vp->xs - 1) * hexagonUnit[sides].x;
+			vp->hexagonList[sides].y =
+				((vp->ys - 1) * hexagonUnit[sides].y / 2) * 4 / 3;
 		}
 	} else if (vp->neighbors == 4 || vp->neighbors == 8) {
 		if (vp->width < 2)
@@ -656,7 +675,7 @@ init_voters(ModeInfo * mi)
 		vp->xb = (vp->width - vp->xs * vp->ncols) / 2;
 		vp->yb = (vp->height - vp->ys * vp->nrows) / 2;
 	} else {		/* TRI */
-		int         orient, i;
+		int         orient, sides;
 
 		if (vp->width < 2)
 			vp->width = 2;
@@ -680,11 +699,11 @@ init_voters(ModeInfo * mi)
 		vp->xb = (vp->width - vp->xs * vp->ncols) / 2 + vp->xs / 2;
 		vp->yb = (vp->height - vp->ys * vp->nrows) / 2 + vp->ys / 2;
 		for (orient = 0; orient < 2; orient++) {
-			for (i = 0; i < 3; i++) {
-				vp->triangleList[orient][i].x =
-					(vp->xs - 2) * triangleUnit[orient][i].x;
-				vp->triangleList[orient][i].y =
-					(vp->ys - 2) * triangleUnit[orient][i].y;
+			for (sides = 0; sides < 3; sides++) {
+				vp->triangleList[orient][sides].x =
+					(vp->xs - 2) * triangleUnit[orient][sides].x;
+				vp->triangleList[orient][sides].y =
+					(vp->ys - 2) * triangleUnit[orient][sides].y;
 			}
 		}
 	}
@@ -802,3 +821,5 @@ release_voters(ModeInfo * mi)
 		voters = NULL;
 	}
 }
+
+#endif /* MODE_voters */
