@@ -287,7 +287,7 @@ draw_xjack(ModeInfo * mi)
 				Bool overstrike;
 
 				do {
-					XDrawString (display, window, jp->gc,
+					(void) XDrawString (display, window, jp->gc,
 							(jp->x * jp->char_width) + jp->hspace + xshift,
 							(jp->y * jp->line_height) + jp->vspace + mode_font->ascent + yshift,
 							&c, 1);
@@ -394,7 +394,7 @@ draw_xjack(ModeInfo * mi)
 			const char *n2 = "NFS server overlook ok.";
 
 			while (*n1) {
-				XDrawString (display, window, jp->gc,
+				(void) XDrawString (display, window, jp->gc,
 									(jp->x * jp->char_width) + jp->hspace,
 									(jp->y * jp->line_height) + jp->vspace + mode_font->ascent,
 									n1, 1);
@@ -408,7 +408,7 @@ draw_xjack(ModeInfo * mi)
 			usleep (5000000);
 #endif
 			while (*n2) {
-				XDrawString (display, window, jp->gc,
+				(void) XDrawString (display, window, jp->gc,
 								(jp->x * jp->char_width) + jp->hspace,
 								(jp->y * jp->line_height) + jp->vspace + mode_font->ascent,
 								n2, 1);
