@@ -59,7 +59,7 @@ LockStruct  LockProcs[] =
 	 "Shows a meadow of daisies", (void *) NULL},
 	{"dclock",
 	 10000, 1, 10000, 1, 0.2,
-	 "Shows a floating digital clock", (void *) NULL},
+	 "Shows a floating digital clock or message", (void *) NULL},
 	{"demon",
 	 50000, 0, 1000, -7, 1.0,
 	 "Shows Griffeath's cellular automata", (void *) NULL},
@@ -68,7 +68,7 @@ LockStruct  LockProcs[] =
 	 "Shows eyes following a bouncing grelb", (void *) NULL},
 	{"flag",
 	 50000, 1, 1000, -7, 1.0,
-	 "Shows a flying flag of your operating system", (void *) NULL},
+	 "Shows a flying flag image", (void *) NULL},
 	{"flame",
 	 750000, 20, 10000, 1, 1.0,
 	 "Shows cosmic flame fractals", (void *) NULL},
