@@ -583,6 +583,7 @@ extern void release_last_mode(ModeInfo *);
 #define MODE_swirl
 #define MODE_tetris
 #define MODE_thornbird
+#define MODE_tik_tak
 #define MODE_triangle
 #define MODE_tube
 #define MODE_turtle
@@ -1342,6 +1343,14 @@ extern ModeHook change_thornbird;
 extern ModeSpecOpt thornbird_opts;
 #endif
 
+#ifdef MODE_tik_tak
+extern ModeHook init_tik_tak;
+extern ModeHook draw_tik_tak;
+extern ModeHook release_tik_tak;
+extern ModeHook refresh_tik_tak;
+extern ModeSpecOpt tik_tak_opts;
+#endif
+
 #ifdef MODE_triangle
 extern ModeHook init_triangle;
 extern ModeHook draw_triangle;
