@@ -104,8 +104,6 @@ static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
 #define DECW$C_WS_DSP_TRANSPORT 2	/*  taken from wsdriver.lis */
 #define IO$M_WS_DISPLAY 0x00000040	/* taken from wsdriver */
 
-extern void checkResources(void);
-
 struct descriptor_t {		/* descriptor structure         */
 	unsigned short len;
 	unsigned char type;
@@ -1570,8 +1568,11 @@ printvar(char *className, argtype var)
 }
 
 static void
-getServerResources(Display * display, char *homeenv, char **custom,
-		   XrmDatabase * RDB, XrmDatabase * serverDB)
+getServerResources(Display * display, char *homeenv,
+#ifdef CUSTOMIZATION
+  char **custom,
+#endif
+  XrmDatabase * RDB, XrmDatabase * serverDB)
 {
 	char       *serverString;
 
@@ -1607,8 +1608,11 @@ getServerResources(Display * display, char *homeenv, char **custom,
 }
 
 static void
-getAppResources(char *homeenv, char **custom,
-	   XrmDatabase * RDB, XrmDatabase * serverDB, int *argc, char **argv)
+getAppResources(char *homeenv, char **custom, XrmDatabase * RDB,
+#ifdef CUSTOMIZATION
+	   XrmDatabase * serverDB,
+#endif
+	   int *argc, char **argv)
 {
 	char       *env;
 	char       *userpath;
@@ -1714,10 +1718,10 @@ getResources(Display ** displayp, int argc, char **argv)
 extern void XlockrmParseCommand(
     XrmDatabase		*pdb,		/* data base */
     register XrmOptionDescList options, /* pointer to table of valid options */
-    int			num_options,	/* number of options		     */
-    char	*prefix,	/* name to prefix resources with     */
-    int			*argc,		/* address of argument count 	     */
-    char		**argv);		/* argument list (command line)	     */
+    int                 num_options,	/* number of options		     */
+    char               *prefix,		/* name to prefix resources with     */
+    int                *arg_c,		/* address of argument count 	     */
+    char              **arg_v);		/* argument list (command line)	     */
 
 #if defined( USE_AUTO_LOGOUT ) || defined( USE_BUTTON_LOGOUT )
 	extern int  fullLock();
@@ -1764,10 +1768,10 @@ extern void XlockrmParseCommand(
 	checkDisplay();
 #else
 	custom = "";
-	getAppResources(homeenv, &custom, &RDB, &serverDB, &argc, argv);
+	getAppResources(homeenv, &custom, &RDB, &argc, argv);
 	openDisplay(displayp);
 	checkDisplay();
-	getServerResources(*displayp, homeenv, &custom, &RDB, &serverDB);
+	getServerResources(*displayp, homeenv, &RDB, &serverDB);
 #endif
 
 #ifdef USE_MODULES
@@ -1979,12 +1983,13 @@ extern void XlockrmParseCommand(
 #endif
 #endif
 #ifdef USE_BUTTON_LOGOUT
-#if ( USE_BUTTON_LOGOUT > 0 )	/* Could be USER defined if 0 */
+#if ( USE_BUTTON_LOGOUT > 0 )	/* Could be USER defined if <= 0 */
 		if (logoutButton > USE_BUTTON_LOGOUT)
 			logoutButton = USE_BUTTON_LOGOUT;
 		else if (logoutButton <= 0)	/* Handle 0 as a special case */
 			logoutButton = USE_BUTTON_LOGOUT;
-#else
+#endif
+#if ( USE_BUTTON_LOGOUT == 0 )
 		if (logoutButton <= 0)	/* Handle 0 as a special case */
 			(void) sscanf(DEF_BUTTON_LOGOUT, "%d", &logoutButton);
 #endif
