@@ -90,6 +90,7 @@ free_spline(spline * s)
 	(void) free((void *) s);
 }
 
+/* PURIFY says that this leaks */
 static void
 grow_spline_points(spline * s)
 {
@@ -144,12 +145,12 @@ add_line(spline * s,
 		grow_spline_points(s);
 
 	if (s->n_points == 0) {
-		s->points[s->n_points].x = x0;
-		s->points[s->n_points].y = y0;
+		s->points[s->n_points].x = (short) x0;
+		s->points[s->n_points].y = (short) y0;
 		s->n_points += 1;
 	}
-	s->points[s->n_points].x = x1;
-	s->points[s->n_points].y = y1;
+	s->points[s->n_points].x = (short) x1;
+	s->points[s->n_points].y = (short) y1;
 	s->n_points += 1;
 }
 
@@ -218,7 +219,7 @@ compute_spline(spline * s)
 		     s->control_y[0], s->control_x[1], s->control_y[1],
 		     s->control_x[2], s->control_y[2]);
 
-	for (i = 1; i < s->n_controls - 2; i++)
+	for (i = 1; i < (int) s->n_controls - 2; i++)
 		calc_section(s, s->control_x[i - 1], s->control_y[i - 1],
 			     s->control_x[i], s->control_y[i],
 			     s->control_x[i + 1], s->control_y[i + 1],
@@ -251,7 +252,7 @@ compute_closed_spline(spline * s)
 		     s->control_x[1], s->control_y[1],
 		     s->control_x[2], s->control_y[2]);
 
-	for (i = 1; i < s->n_controls - 2; i++)
+	for (i = 1; i < (int) s->n_controls - 2; i++)
 		calc_section(s, s->control_x[i - 1], s->control_y[i - 1],
 			     s->control_x[i], s->control_y[i],
 			     s->control_x[i + 1], s->control_y[i + 1],
@@ -275,12 +276,12 @@ just_fill_spline(spline * s)
 	while (s->allocated_points < s->n_controls + 1)
 		grow_spline_points(s);
 
-	for (i = 0; i < s->n_controls; i++) {
-		s->points[i].x = s->control_x[i];
-		s->points[i].y = s->control_y[i];
+	for (i = 0; i < (int) s->n_controls; i++) {
+		s->points[i].x = (short) s->control_x[i];
+		s->points[i].y = (short) s->control_y[i];
 	}
-	s->points[s->n_controls].x = s->control_x[0];
-	s->points[s->n_controls].y = s->control_y[0];
+	s->points[s->n_controls].x = (short) s->control_x[0];
+	s->points[s->n_controls].y = (short) s->control_y[0];
 	s->n_points = s->n_controls + 1;
 }
 
@@ -291,7 +292,7 @@ append_spline_points(spline * s1, spline * s2)
 
 	while (s1->allocated_points < s1->n_points + s2->n_points)
 		grow_spline_points(s1);
-	for (i = s1->n_points; i < s1->n_points + s2->n_points; i++) {
+	for (i = s1->n_points; i < (int) (s1->n_points + s2->n_points); i++) {
 		s1->points[i].x = s2->points[i - s1->n_points].x;
 		s1->points[i].y = s2->points[i - s1->n_points].y;
 	}
@@ -318,7 +319,7 @@ spline_bounding_box(spline * s, XRectangle * rectangle_out)
 	min_y = s->points[0].y;
 	max_y = min_y;
 
-	for (i = 1; i < s->n_points; i++) {
+	for (i = 1; i < (int) s->n_points; i++) {
 		if (s->points[i].x < min_x)
 			min_x = s->points[i].x;
 		if (s->points[i].x > max_x)
