@@ -19,7 +19,7 @@ extern void defaultVisualInfo(Display * display, int screen);
 extern Bool setupColormap(ModeInfo * mi, int *colors, Bool * truecolor,
   unsigned long *redmask, unsigned long *bluemask, unsigned long *greenmask);
 extern int  visualClassFromName(char *name);
-extern char *nameOfVisualClass(int visualclass);
+extern const char *nameOfVisualClass(int visualclass);
 extern Bool has_writable_cells(ModeInfo * mi);
 extern Bool fixedColors(ModeInfo * mi);
 #ifdef __cplusplus
