@@ -134,9 +134,14 @@ XrmOptionDescRec options[100];
 
 #define XSCREENSAVER_PREF 1	/* Disagreements handled with this  :) */
 
-#else /* STANDALONE */
+#else /* !STANDALONE */
+#include <sys/types.h>
+#ifdef __NetBSD__
+#include <signal.h>
+#else /* !__NetBSD__ */
 #include <sys/signal.h>
-# include <X11/Xlib.h>
+#endif /* __NetBSD__ */
+#include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xos.h>
 #include <X11/Xresource.h>
@@ -166,7 +171,9 @@ XrmOptionDescRec options[100];
 
 /* THIS MAY SOON BE DEFUNCT, SHOULD WORK NOW THOUGH FOR IMAKE */
 #define HAVE_GLBINDTEXTURE 1
+#if !defined(__cplusplus) && !defined(c_plusplus)
 #define inline
+#endif
 #ifdef AIXV3
 #define HAVE_SYS_SELECT_H 1
 #else
@@ -292,7 +299,6 @@ XrmOptionDescRec options[100];
 #if VMS
 #include <unixlib.h>
 #endif
-#include <sys/types.h>
 #if 0
 #ifndef uid_t
 #define uid_t int
