@@ -121,8 +121,9 @@ static LockStruct LockProcs[] =
 #endif
 {"swarm","Shows a swarm of bees following a wasp"},
 {"swirl","Shows animated swirling patterns"},
-{"tetris","Shows tetris"},
+{"tetris","Shows an autoplaying tetris game"},
 {"thornbird","Shows an animated bird in a thorn bush fractal map"},
+{"tik_tak","Shows rotating polygons"},
 {"triangle","Shows a triangle mountain range"},
 {"tube","Shows an animated tube"},
 {"turtle","Shows turtle fractals"},
